<?php

/**
 * @file
 * Setka Editor API functions.
 */

/**
 * Current_Build - Returns last built files for integration.
 *
 * @param string $token
 *   License key.
 *
 * @return object
 *   Result of http request.
 *
 * @see \drupal_http_request()
 */
function setka_editor_api_get_current_build($token) {
  return setka_editor_api_http_request('GET', '/api/v1/custom/builds/current', array('token' => $token));
}

/**
 * Pushes information about plugin, site and CMS to Style Manager.
 *
 * @param string $token
 *   License key.
 */
function setka_editor_api_push_system_info($token) {
  global $base_url;

  $appVersion = VERSION;
  $moduleInfo = system_get_info('module', 'setka_editor');
  $pluginVersion = $moduleInfo['version'];
  $pluginVersion = empty($pluginVersion) ? '7.x-1.0' : $pluginVersion;

  $response = setka_editor_api_http_request('POST', '/api/v1/drupal/current_theme.json',
    array(
      'token' => $token,
      'app_version' => $appVersion,
      'plugin_version' => $pluginVersion,
      'domain' => $base_url,
    ),
    FALSE
  );

  if (isset($response->error)) {
    watchdog('setka_editor', 'System info push error: @error', array('@error' => $response->error), WATCHDOG_ERROR);
  }
}

/**
 * Make http request to Setka Editor API.
 *
 * @param string $method
 *   HTTP request method (GET, POST, etc.).
 * @param string $url
 *   A string containing API URI.
 * @param array $params
 *   An array containing API parameters.
 * @param bool $add_content_type_header
 *   Add 'Content-Type:application/json' header if TRUE.
 *
 * @return object
 *   Result of http request.
 *
 * @see \drupal_http_request()
 */
function setka_editor_api_http_request($method, $url, array $params = array(), $add_content_type_header = TRUE) {
  $options = array();

  if ($add_content_type_header) {
    $options['headers'] = array('Content-Type:application/json');
  }

  $options['method'] = $method;
  if ($method == 'GET') {
    $url = setka_editor_get_setka_api_domain() . $url . '?' . http_build_query($params);
  }
  elseif ($method == 'POST') {
    $url = setka_editor_get_setka_api_domain() . $url;
    $options['data'] = http_build_query($params);
  }

  return drupal_http_request($url, $options);
}
