(function($) {

  /**
   * Setka Editor initialization.
   */
  Drupal.behaviors.setka_editor_edit = {
    attach: function (context, settings) {

      var detectToolbar = function () {
        // Try to search toolbar in parent.document context if Overlay module enabled.
        var $body = $('body', parent.document);
        if ($body.length === 0) {
          $body = $('body');
        }
        // admin_menu
        if ($body.hasClass('admin-menu')) {
          return $('#admin-menu', $body).height();
        }
        // toolbar
        if ($body.hasClass('toolbar')) {
          return $('#toolbar', $body).height();
        }

      };

      if (Drupal.settings.setka_editor) { // Settings attached to the form
        if ($('.stk-editor').length === 0) {
          return;
        }
        var publicToken = Drupal.settings.setka_editor.public_token || '';
        var jsonUrl = Drupal.settings.setka_editor.json_meta_data_url || false;
        var restApiUrl = Drupal.settings.setka_editor.restApiUrl || false;
        var images = Drupal.settings.setka_editor.images || false;
        var restApiRequestPayload = Drupal.settings.setka_editor.restApiRequestPayload || {};
        var headerTopOffset = Drupal.settings.setka_editor.headerTopOffset || 0;
        var footerBottomOffset = Drupal.settings.setka_editor.footerBottomOffset || 0;
        var resetTheme = Drupal.settings.setka_editor.resetTheme || false;
        var resetLayout = Drupal.settings.setka_editor.resetLayout || false;
        var uploadMaxSize = Drupal.settings.setka_editor.setkaEditorUploadMaxSize;
        var config = [];
        var assets = [];
        var storage = $('#setka-editor-storage').val();
        var storageObj = false;
        var postContent = '';
        if (storage.length > 2) {
          storageObj = JSON.parse(storage);
        }
        if (jsonUrl) {
          if (!resetTheme && !resetLayout) {
            $.getJSON(jsonUrl, function (data) {
              config = data.config;
              assets = data.assets;
              config.public_token = publicToken;
              config.token = publicToken;
              config.uploadMaxSize = uploadMaxSize;
              config.headerTopOffset = detectToolbar() || headerTopOffset;
              config.footerBottomOffset = footerBottomOffset;
              if (storageObj) {
                config.theme = storageObj.themeId;
                config.layout = storageObj.layoutId;
                postContent = storageObj.contents;
              }
              if (restApiUrl) {
                config.restApiUrl = restApiUrl;
                config.restApiRequestPayload = restApiRequestPayload;
              }
              if (images) {
                assets.images = images;
              }
              if (SetkaEditor) {
                try {
                  SetkaEditor.start(config, assets);
                  SetkaEditor.replaceHTML(postContent);
                }
                catch (ex) {
                  console.error(ex);
                }
              }
              else {
                console.error('Setka Editor was not loaded.');
              }
            });
            if (SetkaEditor) {
              $('input.form-submit').parents('form').submit(function (e) {
                var usedImages = [];
                $.each(SetkaEditor.getImages(), function (index, image) {
                  usedImages.push(image.id);
                });
                var currentTheme = SetkaEditor.getCurrentTheme();
                var textareaData = {
                  'themeId': currentTheme.id,
                  'layoutId': SetkaEditor.getCurrentLayout().id,
                  'images': usedImages,
                  'contents': SetkaEditor.getHTML({includeContainer: true})
                };
                if ('kit_id' in currentTheme) {
                  Object.assign(textareaData, {'typekitId': currentTheme.kit_id});
                }
                var textValue = JSON.stringify(textareaData);
                $('#setka-editor-storage').text(textValue);
              });
            }
          }
          else {
            if (storageObj) {
              postContent = storageObj.contents;
              if (postContent !== '') {
                var rawTextarea = document.createElement("textarea");
                rawTextarea.disabled = true;
                rawTextarea.style.width = '100%';
                rawTextarea.style.height = '200px';
                rawTextarea.setAttribute('class', 'form-textarea');
                rawTextarea.innerHTML = postContent;
                var buttonValue = Drupal.t('Copy raw post');
                var copyRawButton = document.createElement("input");
                copyRawButton.setAttribute('type', 'button');
                copyRawButton.setAttribute('value', buttonValue);
                copyRawButton.setAttribute('class', 'form-submit');
                copyRawButton.addEventListener("click", function () {
                  rawTextarea.disabled = false;
                  rawTextarea.focus();
                  rawTextarea.select();
                  document.execCommand('copy');
                  rawTextarea.disabled = true;
                });
                var setkaEditorElement = $('#setka-editor');
                setkaEditorElement.after(copyRawButton);
                setkaEditorElement.after(rawTextarea);
              }
            }
          }
        }
        else {
          console.error('Setka Editor was not enabled.');
        }

      }
    }
  };

})(jQuery);
